[Libreoffice-commits] core.git: dbaccess/source include/sfx2 sd/source sfx2/inc sfx2/source

Caolán McNamara (via logerrit) logerrit at kemper.freedesktop.org
Thu Oct 22 19:08:35 UTC 2020


 dbaccess/source/ui/app/AppIconControl.cxx             |   12 +-
 dbaccess/source/ui/app/AppIconControl.hxx             |    2 
 include/sfx2/templatelocalview.hxx                    |    2 
 include/sfx2/thumbnailview.hxx                        |   10 -
 sd/source/ui/sidebar/MasterPageContainerProviders.cxx |    2 
 sfx2/inc/emojiview.hxx                                |    2 
 sfx2/inc/recentdocsview.hxx                           |    2 
 sfx2/source/control/emojiview.cxx                     |    8 -
 sfx2/source/control/recentdocsview.cxx                |   14 +-
 sfx2/source/control/recentdocsviewitem.cxx            |    2 
 sfx2/source/control/templatedefaultview.cxx           |    4 
 sfx2/source/control/templatelocalview.cxx             |    8 -
 sfx2/source/control/templatesearchview.cxx            |    8 -
 sfx2/source/control/thumbnailview.cxx                 |  102 +++++++++---------
 sfx2/source/control/thumbnailviewacc.cxx              |   88 +++++++--------
 sfx2/source/control/thumbnailviewacc.hxx              |   12 +-
 sfx2/source/inc/templatesearchview.hxx                |    2 
 17 files changed, 140 insertions(+), 140 deletions(-)

New commits:
commit 1002675c64315b75d5a2ff75431d8de8d52459d9
Author:     Caolán McNamara <caolanm at redhat.com>
AuthorDate: Wed Oct 21 20:47:31 2020 +0100
Commit:     Caolán McNamara <caolanm at redhat.com>
CommitDate: Thu Oct 22 21:07:46 2020 +0200

    rename SfxThumbnailView back to ThumbnailView
    
    Change-Id: I07251905c3bf5bccb23c684d47ed34e79dde55fb
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/104645
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/dbaccess/source/ui/app/AppIconControl.cxx b/dbaccess/source/ui/app/AppIconControl.cxx
index 29a1c35a8d84..261855982604 100644
--- a/dbaccess/source/ui/app/AppIconControl.cxx
+++ b/dbaccess/source/ui/app/AppIconControl.cxx
@@ -57,7 +57,7 @@ public:
 };
 
 OApplicationIconControl::OApplicationIconControl(std::unique_ptr<weld::ScrolledWindow> xScroll)
-    : SfxThumbnailView(std::move(xScroll), nullptr)
+    : ThumbnailView(std::move(xScroll), nullptr)
     , m_pActionListener(nullptr)
     , m_nMaxWidth(0)
     , m_nMaxHeight(0)
@@ -126,7 +126,7 @@ void OApplicationIconControl::Resize()
     // fill the full width of the allocated area and give two lines of space to
     // center the title in
     setItemDimensions(GetOutputSizePixel().Width(), m_nMaxHeight, GetTextHeight() * 2, 0);
-    SfxThumbnailView::Resize();
+    ThumbnailView::Resize();
 }
 
 bool OApplicationIconControl::IsMnemonicChar(sal_Unicode cChar, ElementType& rType) const
@@ -165,12 +165,12 @@ bool OApplicationIconControl::DoKeyShortCut(const KeyEvent& rKEvt)
 
 bool OApplicationIconControl::KeyInput(const KeyEvent& rKEvt)
 {
-    return DoKeyShortCut(rKEvt) || SfxThumbnailView::KeyInput(rKEvt);
+    return DoKeyShortCut(rKEvt) || ThumbnailView::KeyInput(rKEvt);
 }
 
 void OApplicationIconControl::SetDrawingArea(weld::DrawingArea* pDrawingArea)
 {
-    SfxThumbnailView::SetDrawingArea(pDrawingArea);
+    ThumbnailView::SetDrawingArea(pDrawingArea);
     m_xDropTarget.reset(new OApplicationIconControlDropTarget(*this));
 }
 
@@ -203,13 +203,13 @@ OApplicationIconControl::~OApplicationIconControl()
 
 void OApplicationIconControl::GetFocus()
 {
-    SfxThumbnailView::GetFocus();
+    ThumbnailView::GetFocus();
     Invalidate(); // redraw focus rect
 }
 
 void OApplicationIconControl::LoseFocus()
 {
-    SfxThumbnailView::LoseFocus();
+    ThumbnailView::LoseFocus();
     Invalidate(); // redraw focus rect
 }
 
diff --git a/dbaccess/source/ui/app/AppIconControl.hxx b/dbaccess/source/ui/app/AppIconControl.hxx
index 7ca11cef2659..91f81b71a038 100644
--- a/dbaccess/source/ui/app/AppIconControl.hxx
+++ b/dbaccess/source/ui/app/AppIconControl.hxx
@@ -33,7 +33,7 @@ namespace dbaui
     class IconControl;
     class OApplicationIconControlDropTarget;
 
-    class OApplicationIconControl final : public SfxThumbnailView
+    class OApplicationIconControl final : public ThumbnailView
     {
         std::unique_ptr<OApplicationIconControlDropTarget> m_xDropTarget;
         IControlActionListener* m_pActionListener;
diff --git a/include/sfx2/templatelocalview.hxx b/include/sfx2/templatelocalview.hxx
index 5ce620bed4a2..cd2efb89db8f 100644
--- a/include/sfx2/templatelocalview.hxx
+++ b/include/sfx2/templatelocalview.hxx
@@ -63,7 +63,7 @@ private:
     FILTER_APPLICATION mApp;
 };
 
-class SfxTemplateLocalView : public SfxThumbnailView
+class SfxTemplateLocalView : public ThumbnailView
 {
     typedef bool (*selection_cmp_fn)(const ThumbnailViewItem*,const ThumbnailViewItem*);
 
diff --git a/sd/source/ui/sidebar/MasterPageContainerProviders.cxx b/sd/source/ui/sidebar/MasterPageContainerProviders.cxx
index 5197805b7f37..b935673695c0 100644
--- a/sd/source/ui/sidebar/MasterPageContainerProviders.cxx
+++ b/sd/source/ui/sidebar/MasterPageContainerProviders.cxx
@@ -83,7 +83,7 @@ Image TemplatePreviewProvider::operator() (
     SdPage*,
     ::sd::PreviewRenderer&)
 {
-    return Image(SfxThumbnailView::readThumbnail(msURL));
+    return Image(ThumbnailView::readThumbnail(msURL));
 }
 
 int TemplatePreviewProvider::GetCostIndex()
diff --git a/sfx2/inc/emojiview.hxx b/sfx2/inc/emojiview.hxx
index 68cdb962128e..223d38bbbb72 100644
--- a/sfx2/inc/emojiview.hxx
+++ b/sfx2/inc/emojiview.hxx
@@ -49,7 +49,7 @@ private:
 };
 
 
-class EmojiView final : public SfxThumbnailView
+class EmojiView final : public ThumbnailView
 {
 public:
     EmojiView(std::unique_ptr<weld::ScrolledWindow> xWindow);
diff --git a/sfx2/inc/recentdocsview.hxx b/sfx2/inc/recentdocsview.hxx
index 03fd7fda7c33..c8db9bc3c043 100644
--- a/sfx2/inc/recentdocsview.hxx
+++ b/sfx2/inc/recentdocsview.hxx
@@ -55,7 +55,7 @@ template<> struct typed_flags<sfx2::ApplicationType> : is_typed_flags<sfx2::Appl
 namespace sfx2
 {
 
-class RecentDocsView final : public SfxThumbnailView
+class RecentDocsView final : public ThumbnailView
 {
 public:
     RecentDocsView(std::unique_ptr<weld::ScrolledWindow> xWindow, std::unique_ptr<weld::Menu> xMenu);
diff --git a/sfx2/source/control/emojiview.cxx b/sfx2/source/control/emojiview.cxx
index 9e1606d3fc07..63aa9ac602c9 100644
--- a/sfx2/source/control/emojiview.cxx
+++ b/sfx2/source/control/emojiview.cxx
@@ -61,7 +61,7 @@ bool ViewFilter_Category::operator () (const ThumbnailViewItem *pItem)
 }
 
 EmojiView::EmojiView(std::unique_ptr<weld::ScrolledWindow> xWindow)
-    : SfxThumbnailView(std::move(xWindow), nullptr)
+    : ThumbnailView(std::move(xWindow), nullptr)
 {
     // locate json data file
     OUString sPath("$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER "/emojiconfig/emoji.json");
@@ -79,7 +79,7 @@ EmojiView::EmojiView(std::unique_ptr<weld::ScrolledWindow> xWindow)
 
 void EmojiView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
 {
-    SfxThumbnailView::SetDrawingArea(pDrawingArea);
+    ThumbnailView::SetDrawingArea(pDrawingArea);
 
     if (vcl::Window* pDefaultDevice = dynamic_cast<vcl::Window*>(Application::GetDefaultDevice()))
     {
@@ -199,7 +199,7 @@ bool EmojiView::KeyInput( const KeyEvent& rKEvt )
         return true;
     }
 
-    return SfxThumbnailView::KeyInput(rKEvt);
+    return ThumbnailView::KeyInput(rKEvt);
 }
 
 void EmojiView::setInsertEmojiHdl(const Link<ThumbnailViewItem*, void> &rLink)
@@ -215,7 +215,7 @@ void EmojiView::AppendItem(const OUString &rTitle, const OUString &rCategory, co
     pItem->setCategory(rCategory);
     pItem->setHelpText(rName);
 
-    SfxThumbnailView::AppendItem(std::move(pItem));
+    ThumbnailView::AppendItem(std::move(pItem));
 
     CalculateItemPositions();
 }
diff --git a/sfx2/source/control/recentdocsviewitem.cxx b/sfx2/source/control/recentdocsviewitem.cxx
index 090e2881e000..9b73ef2c88ef 100644
--- a/sfx2/source/control/recentdocsviewitem.cxx
+++ b/sfx2/source/control/recentdocsviewitem.cxx
@@ -54,7 +54,7 @@ RecentDocsViewItem::RecentDocsViewItem(sfx2::RecentDocsView &rView, const OUStri
     //fdo#74834: only load thumbnail if the corresponding option is not disabled in the configuration
     if (aThumbnail.IsEmpty() && aURLObj.GetProtocol() == INetProtocol::File &&
             officecfg::Office::Common::History::RecentDocsThumbnail::get())
-        aThumbnail = SfxThumbnailView::readThumbnail(rURL);
+        aThumbnail = ThumbnailView::readThumbnail(rURL);
 
     if (aThumbnail.IsEmpty())
     {
diff --git a/sfx2/source/control/templatedefaultview.cxx b/sfx2/source/control/templatedefaultview.cxx
index 6c4fd3d241eb..a4a769f59308 100644
--- a/sfx2/source/control/templatedefaultview.cxx
+++ b/sfx2/source/control/templatedefaultview.cxx
@@ -27,7 +27,7 @@ TemplateDefaultView::TemplateDefaultView(std::unique_ptr<weld::ScrolledWindow> x
 {
     tools::Rectangle aScreen = Application::GetScreenPosSizePixel(Application::GetDisplayBuiltInScreen());
     mnItemMaxSize = std::min(aScreen.GetWidth(),aScreen.GetHeight()) > 800 ? 256 : 192;
-    SfxThumbnailView::setItemDimensions( mnItemMaxSize, mnItemMaxSize, gnTextHeight, gnItemPadding );
+    ThumbnailView::setItemDimensions( mnItemMaxSize, mnItemMaxSize, gnTextHeight, gnItemPadding );
     updateThumbnailDimensions(mnItemMaxSize);
 
     // startcenter specific settings
@@ -49,7 +49,7 @@ void TemplateDefaultView::showAllTemplates()
 
 bool TemplateDefaultView::KeyInput( const KeyEvent& rKEvt )
 {
-    return SfxThumbnailView::KeyInput(rKEvt);
+    return ThumbnailView::KeyInput(rKEvt);
 }
 
 bool TemplateDefaultView::MouseButtonDown( const MouseEvent& rMEvt )
diff --git a/sfx2/source/control/templatelocalview.cxx b/sfx2/source/control/templatelocalview.cxx
index 157df66e7bcd..ebeee7a76bc7 100644
--- a/sfx2/source/control/templatelocalview.cxx
+++ b/sfx2/source/control/templatelocalview.cxx
@@ -79,7 +79,7 @@ void SfxTemplateLocalView::updateThumbnailDimensions(long itemMaxSize)
 
 SfxTemplateLocalView::SfxTemplateLocalView(std::unique_ptr<weld::ScrolledWindow> xWindow,
                                            std::unique_ptr<weld::Menu> xMenu)
-    : SfxThumbnailView(std::move(xWindow), std::move(xMenu))
+    : ThumbnailView(std::move(xWindow), std::move(xMenu))
     , mnCurRegionId(0)
     , maSelectedItem(nullptr)
     , mnThumbnailWidth(TEMPLATE_THUMBNAIL_MAX_WIDTH)
@@ -760,7 +760,7 @@ void SfxTemplateLocalView::insertItems(const std::vector<TemplateItemProperties>
 bool SfxTemplateLocalView::MouseButtonDown( const MouseEvent& rMEvt )
 {
     GrabFocus();
-    return SfxThumbnailView::MouseButtonDown(rMEvt);
+    return ThumbnailView::MouseButtonDown(rMEvt);
 }
 
 bool SfxTemplateLocalView::Command(const CommandEvent& rCEvt)
@@ -843,7 +843,7 @@ bool SfxTemplateLocalView::KeyInput( const KeyEvent& rKEvt )
         reload();
     }
 
-    return SfxThumbnailView::KeyInput(rKEvt);
+    return ThumbnailView::KeyInput(rKEvt);
 }
 
 void SfxTemplateLocalView::setOpenRegionHdl(const Link<void*,void> &rLink)
@@ -942,7 +942,7 @@ BitmapEx SfxTemplateLocalView::getDefaultThumbnail( const OUString& rPath )
 
 BitmapEx SfxTemplateLocalView::fetchThumbnail (const OUString &msURL, tools::Long width, tools::Long height)
 {
-    return SfxTemplateLocalView::scaleImg(SfxThumbnailView::readThumbnail(msURL), width, height);
+    return SfxTemplateLocalView::scaleImg(ThumbnailView::readThumbnail(msURL), width, height);
 }
 
 void SfxTemplateLocalView::OnItemDblClicked (ThumbnailViewItem *pItem)
diff --git a/sfx2/source/control/templatesearchview.cxx b/sfx2/source/control/templatesearchview.cxx
index 757dc9984767..c0718230db7e 100644
--- a/sfx2/source/control/templatesearchview.cxx
+++ b/sfx2/source/control/templatesearchview.cxx
@@ -27,7 +27,7 @@
 
 TemplateSearchView::TemplateSearchView(std::unique_ptr<weld::ScrolledWindow> xWindow,
                                        std::unique_ptr<weld::Menu> xMenu)
-    : SfxThumbnailView(std::move(xWindow), std::move(xMenu))
+    : ThumbnailView(std::move(xWindow), std::move(xMenu))
     , maSelectedItem(nullptr)
     , maPosition(0,0)
 {
@@ -36,7 +36,7 @@ TemplateSearchView::TemplateSearchView(std::unique_ptr<weld::ScrolledWindow> xWi
 bool TemplateSearchView::MouseButtonDown( const MouseEvent& rMEvt )
 {
     GrabFocus();
-    return SfxThumbnailView::MouseButtonDown(rMEvt);
+    return ThumbnailView::MouseButtonDown(rMEvt);
 }
 
 bool TemplateSearchView::KeyInput( const KeyEvent& rKEvt )
@@ -80,7 +80,7 @@ bool TemplateSearchView::KeyInput( const KeyEvent& rKEvt )
         }
     }
 
-    return SfxThumbnailView::KeyInput(rKEvt);
+    return ThumbnailView::KeyInput(rKEvt);
 }
 
 bool TemplateSearchView::Command(const CommandEvent& rCEvt)
@@ -217,7 +217,7 @@ void TemplateSearchView::AppendItem(sal_uInt16 nAssocItemId, sal_uInt16 nRegionI
     if (SfxTemplateLocalView::IsDefaultTemplate(rPath))
         pItem->showDefaultIcon(true);
 
-    SfxThumbnailView::AppendItem(std::move(pItem));
+    ThumbnailView::AppendItem(std::move(pItem));
 
     CalculateItemPositions();
 }
diff --git a/sfx2/source/control/thumbnailview.cxx b/sfx2/source/control/thumbnailview.cxx
index 6ba29958a35b..ba16ed06aeb7 100644
--- a/sfx2/source/control/thumbnailview.cxx
+++ b/sfx2/source/control/thumbnailview.cxx
@@ -58,7 +58,7 @@ ThumbnailViewBase::~ThumbnailViewBase()
 {
 }
 
-BitmapEx SfxThumbnailView::readThumbnail(const OUString &msURL)
+BitmapEx ThumbnailView::readThumbnail(const OUString &msURL)
 {
     using namespace ::com::sun::star;
     using namespace ::com::sun::star::uno;
@@ -150,7 +150,7 @@ BitmapEx SfxThumbnailView::readThumbnail(const OUString &msURL)
     return aThumbnail;
 }
 
-SfxThumbnailView::SfxThumbnailView(std::unique_ptr<weld::ScrolledWindow> xWindow, std::unique_ptr<weld::Menu> xMenu)
+ThumbnailView::ThumbnailView(std::unique_ptr<weld::ScrolledWindow> xWindow, std::unique_ptr<weld::Menu> xMenu)
     : mnThumbnailHeight(0)
     , mnDisplayHeight(0)
     , mnVItemSpace(-1)
@@ -160,10 +160,10 @@ SfxThumbnailView::SfxThumbnailView(std::unique_ptr<weld::ScrolledWindow> xWindow
     , mxContextMenu(std::move(xMenu))
 {
     ImplInit();
-    mxScrolledWindow->connect_vadjustment_changed(LINK(this, SfxThumbnailView, ImplScrollHdl));
+    mxScrolledWindow->connect_vadjustment_changed(LINK(this, ThumbnailView, ImplScrollHdl));
 }
 
-SfxThumbnailView::~SfxThumbnailView()
+ThumbnailView::~ThumbnailView()
 {
     css::uno::Reference< css::lang::XComponent> xComponent(mxAccessible, css::uno::UNO_QUERY);
 
@@ -175,7 +175,7 @@ SfxThumbnailView::~SfxThumbnailView()
     ImplDeleteItems();
 }
 
-bool SfxThumbnailView::MouseMove(const MouseEvent& rMEvt)
+bool ThumbnailView::MouseMove(const MouseEvent& rMEvt)
 {
     size_t nItemCount = mFilteredItemList.size();
     Point aPoint = rMEvt.GetPosPixel();
@@ -191,7 +191,7 @@ bool SfxThumbnailView::MouseMove(const MouseEvent& rMEvt)
     return true;
 }
 
-OUString SfxThumbnailView::RequestHelp(tools::Rectangle& rHelpRect)
+OUString ThumbnailView::RequestHelp(tools::Rectangle& rHelpRect)
 {
     if (!mbShowTooltips)
         return OUString();
@@ -214,7 +214,7 @@ OUString SfxThumbnailView::RequestHelp(tools::Rectangle& rHelpRect)
     return OUString();
 }
 
-void SfxThumbnailView::AppendItem(std::unique_ptr<ThumbnailViewItem> pItem)
+void ThumbnailView::AppendItem(std::unique_ptr<ThumbnailViewItem> pItem)
 {
     if (maFilterFunc(pItem.get()))
     {
@@ -235,7 +235,7 @@ void SfxThumbnailView::AppendItem(std::unique_ptr<ThumbnailViewItem> pItem)
     mItemList.push_back(std::move(pItem));
 }
 
-void SfxThumbnailView::ImplInit()
+void ThumbnailView::ImplInit()
 {
     mnItemWidth = 0;
     mnItemHeight = 0;
@@ -269,7 +269,7 @@ void SfxThumbnailView::ImplInit()
     mpItemAttrs->nMaxTextLength = 0;
 }
 
-void SfxThumbnailView::UpdateColors()
+void ThumbnailView::UpdateColors()
 {
     mpItemAttrs->aFillColor = maFillColor.getBColor();
     mpItemAttrs->aTextColor = maTextColor.getBColor();
@@ -280,7 +280,7 @@ void SfxThumbnailView::UpdateColors()
     mpItemAttrs->fHighlightTransparence = mfHighlightTransparence;
 }
 
-void SfxThumbnailView::ImplDeleteItems()
+void ThumbnailView::ImplDeleteItems()
 {
     const size_t n = mItemList.size();
 
@@ -314,7 +314,7 @@ void SfxThumbnailView::ImplDeleteItems()
     mpStartSelRange = mFilteredItemList.end();
 }
 
-void SfxThumbnailView::DrawItem(ThumbnailViewItem const *pItem)
+void ThumbnailView::DrawItem(ThumbnailViewItem const *pItem)
 {
     if (pItem->isVisible())
     {
@@ -325,22 +325,22 @@ void SfxThumbnailView::DrawItem(ThumbnailViewItem const *pItem)
     }
 }
 
-void SfxThumbnailView::OnItemDblClicked (ThumbnailViewItem*)
+void ThumbnailView::OnItemDblClicked (ThumbnailViewItem*)
 {
 }
 
-css::uno::Reference< css::accessibility::XAccessible > SfxThumbnailView::CreateAccessible()
+css::uno::Reference< css::accessibility::XAccessible > ThumbnailView::CreateAccessible()
 {
-    mxAccessible.set(new SfxThumbnailViewAcc(this));
+    mxAccessible.set(new ThumbnailViewAcc(this));
     return mxAccessible;
 }
 
-css::uno::Reference< css::accessibility::XAccessible > SfxThumbnailView::getAccessible()
+css::uno::Reference< css::accessibility::XAccessible > ThumbnailView::getAccessible()
 {
     return mxAccessible;
 }
 
-void SfxThumbnailView::CalculateItemPositions(bool bScrollBarUsed)
+void ThumbnailView::CalculateItemPositions(bool bScrollBarUsed)
 {
     if (!mnItemHeight || !mnItemWidth)
         return;
@@ -491,7 +491,7 @@ void SfxThumbnailView::CalculateItemPositions(bool bScrollBarUsed)
         mxScrolledWindow->set_vpolicy(mbScroll ? VclPolicyType::ALWAYS : VclPolicyType::NEVER);
 }
 
-size_t SfxThumbnailView::ImplGetItem( const Point& rPos ) const
+size_t ThumbnailView::ImplGetItem( const Point& rPos ) const
 {
     if ( !mbHasVisibleItems )
     {
@@ -507,12 +507,12 @@ size_t SfxThumbnailView::ImplGetItem( const Point& rPos ) const
     return THUMBNAILVIEW_ITEM_NOTFOUND;
 }
 
-ThumbnailViewItem* SfxThumbnailView::ImplGetItem( size_t nPos )
+ThumbnailViewItem* ThumbnailView::ImplGetItem( size_t nPos )
 {
     return ( nPos < mFilteredItemList.size() ) ? mFilteredItemList[nPos] : nullptr;
 }
 
-sal_uInt16 SfxThumbnailView::ImplGetVisibleItemCount() const
+sal_uInt16 ThumbnailView::ImplGetVisibleItemCount() const
 {
     sal_uInt16 nRet = 0;
     const size_t nItemCount = mItemList.size();
@@ -526,7 +526,7 @@ sal_uInt16 SfxThumbnailView::ImplGetVisibleItemCount() const
     return nRet;
 }
 
-ThumbnailViewItem* SfxThumbnailView::ImplGetVisibleItem( sal_uInt16 nVisiblePos )
+ThumbnailViewItem* ThumbnailView::ImplGetVisibleItem( sal_uInt16 nVisiblePos )
 {
     const size_t nItemCount = mItemList.size();
 
@@ -541,28 +541,28 @@ ThumbnailViewItem* SfxThumbnailView::ImplGetVisibleItem( sal_uInt16 nVisiblePos
     return nullptr;
 }
 
-void SfxThumbnailView::ImplFireAccessibleEvent( short nEventId, const css::uno::Any& rOldValue, const css::uno::Any& rNewValue )
+void ThumbnailView::ImplFireAccessibleEvent( short nEventId, const css::uno::Any& rOldValue, const css::uno::Any& rNewValue )
 {
-    SfxThumbnailViewAcc* pAcc = SfxThumbnailViewAcc::getImplementation(mxAccessible);
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation(mxAccessible);
 
     if( pAcc )
         pAcc->FireAccessibleEvent( nEventId, rOldValue, rNewValue );
 }
 
-bool SfxThumbnailView::ImplHasAccessibleListeners()
+bool ThumbnailView::ImplHasAccessibleListeners()
 {
-    SfxThumbnailViewAcc* pAcc = SfxThumbnailViewAcc::getImplementation(mxAccessible);
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation(mxAccessible);
     return( pAcc && pAcc->HasAccessibleListeners() );
 }
 
-IMPL_LINK_NOARG(SfxThumbnailView, ImplScrollHdl, weld::ScrolledWindow&, void)
+IMPL_LINK_NOARG(ThumbnailView, ImplScrollHdl, weld::ScrolledWindow&, void)
 {
     CalculateItemPositions(true);
     if (IsReallyVisible() && IsUpdateMode())
         Invalidate();
 }
 
-bool SfxThumbnailView::KeyInput( const KeyEvent& rKEvt )
+bool ThumbnailView::KeyInput( const KeyEvent& rKEvt )
 {
     bool bHandled = true;
 
@@ -745,7 +745,7 @@ bool SfxThumbnailView::KeyInput( const KeyEvent& rKEvt )
     return bHandled;
 }
 
-void SfxThumbnailView::MakeItemVisible( sal_uInt16 nItemId )
+void ThumbnailView::MakeItemVisible( sal_uInt16 nItemId )
 {
     // Get the item row
     size_t nPos = 0;
@@ -771,7 +771,7 @@ void SfxThumbnailView::MakeItemVisible( sal_uInt16 nItemId )
     Invalidate();
 }
 
-bool SfxThumbnailView::MouseButtonDown( const MouseEvent& rMEvt )
+bool ThumbnailView::MouseButtonDown( const MouseEvent& rMEvt )
 {
     GrabFocus();
 
@@ -890,7 +890,7 @@ bool SfxThumbnailView::MouseButtonDown( const MouseEvent& rMEvt )
     return true;
 }
 
-void SfxThumbnailView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
+void ThumbnailView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
 {
     CustomWidgetController::SetDrawingArea(pDrawingArea);
 
@@ -904,7 +904,7 @@ void SfxThumbnailView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
     SetOutputSizePixel(pDrawingArea->get_preferred_size());
 }
 
-void SfxThumbnailView::Paint(vcl::RenderContext& rRenderContext, const ::tools::Rectangle& /*rRect*/)
+void ThumbnailView::Paint(vcl::RenderContext& rRenderContext, const ::tools::Rectangle& /*rRect*/)
 {
     rRenderContext.Push(PushFlags::ALL);
 
@@ -939,7 +939,7 @@ void SfxThumbnailView::Paint(vcl::RenderContext& rRenderContext, const ::tools::
     rRenderContext.Pop();
 }
 
-void SfxThumbnailView::GetFocus()
+void ThumbnailView::GetFocus()
 {
     // Select the first item if nothing selected
     int nSelected = -1;
@@ -955,24 +955,24 @@ void SfxThumbnailView::GetFocus()
     }
 
     // Tell the accessible object that we got the focus.
-    SfxThumbnailViewAcc* pAcc = SfxThumbnailViewAcc::getImplementation(mxAccessible);
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation(mxAccessible);
     if( pAcc )
         pAcc->GetFocus();
 
     CustomWidgetController::GetFocus();
 }
 
-void SfxThumbnailView::LoseFocus()
+void ThumbnailView::LoseFocus()
 {
     CustomWidgetController::LoseFocus();
 
     // Tell the accessible object that we lost the focus.
-    SfxThumbnailViewAcc* pAcc = SfxThumbnailViewAcc::getImplementation(mxAccessible);
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation(mxAccessible);
     if( pAcc )
         pAcc->LoseFocus();
 }
 
-void SfxThumbnailView::Resize()
+void ThumbnailView::Resize()
 {
     CustomWidgetController::Resize();
     CalculateItemPositions();
@@ -981,7 +981,7 @@ void SfxThumbnailView::Resize()
         Invalidate();
 }
 
-void SfxThumbnailView::RemoveItem( sal_uInt16 nItemId )
+void ThumbnailView::RemoveItem( sal_uInt16 nItemId )
 {
     size_t nPos = GetItemPos( nItemId );
 
@@ -1024,7 +1024,7 @@ void SfxThumbnailView::RemoveItem( sal_uInt16 nItemId )
         Invalidate();
 }
 
-void SfxThumbnailView::Clear()
+void ThumbnailView::Clear()
 {
     ImplDeleteItems();
 
@@ -1037,7 +1037,7 @@ void SfxThumbnailView::Clear()
         Invalidate();
 }
 
-void SfxThumbnailView::updateItems (std::vector<std::unique_ptr<ThumbnailViewItem>> items)
+void ThumbnailView::updateItems (std::vector<std::unique_ptr<ThumbnailViewItem>> items)
 {
     ImplDeleteItems();
 
@@ -1049,7 +1049,7 @@ void SfxThumbnailView::updateItems (std::vector<std::unique_ptr<ThumbnailViewIte
     filterItems(maFilterFunc);
 }
 
-size_t SfxThumbnailView::GetItemPos( sal_uInt16 nItemId ) const
+size_t ThumbnailView::GetItemPos( sal_uInt16 nItemId ) const
 {
     for ( size_t i = 0, n = mFilteredItemList.size(); i < n; ++i ) {
         if ( mFilteredItemList[i]->mnId == nItemId ) {
@@ -1059,12 +1059,12 @@ size_t SfxThumbnailView::GetItemPos( sal_uInt16 nItemId ) const
     return THUMBNAILVIEW_ITEM_NOTFOUND;
 }
 
-sal_uInt16 SfxThumbnailView::GetItemId( size_t nPos ) const
+sal_uInt16 ThumbnailView::GetItemId( size_t nPos ) const
 {
     return ( nPos < mFilteredItemList.size() ) ? mFilteredItemList[nPos]->mnId : 0 ;
 }
 
-sal_uInt16 SfxThumbnailView::GetItemId( const Point& rPos ) const
+sal_uInt16 ThumbnailView::GetItemId( const Point& rPos ) const
 {
     size_t nItemPos = ImplGetItem( rPos );
     if ( nItemPos != THUMBNAILVIEW_ITEM_NOTFOUND )
@@ -1073,17 +1073,17 @@ sal_uInt16 SfxThumbnailView::GetItemId( const Point& rPos ) const
     return 0;
 }
 
-sal_uInt16 SfxThumbnailView::getNextItemId() const
+sal_uInt16 ThumbnailView::getNextItemId() const
 {
     return mItemList.empty() ? 1 : mItemList.back()->mnId + 1;
 }
 
-void SfxThumbnailView::setItemMaxTextLength(sal_uInt32 nLength)
+void ThumbnailView::setItemMaxTextLength(sal_uInt32 nLength)
 {
     mpItemAttrs->nMaxTextLength = nLength;
 }
 
-void SfxThumbnailView::setItemDimensions(tools::Long itemWidth, tools::Long thumbnailHeight, tools::Long displayHeight, int itemPadding)
+void ThumbnailView::setItemDimensions(tools::Long itemWidth, tools::Long thumbnailHeight, tools::Long displayHeight, int itemPadding)
 {
     mnItemWidth = itemWidth + 2*itemPadding;
     mnThumbnailHeight = thumbnailHeight;
@@ -1092,7 +1092,7 @@ void SfxThumbnailView::setItemDimensions(tools::Long itemWidth, tools::Long thum
     mnItemHeight = mnDisplayHeight + mnThumbnailHeight + 2*itemPadding;
 }
 
-void SfxThumbnailView::SelectItem( sal_uInt16 nItemId )
+void ThumbnailView::SelectItem( sal_uInt16 nItemId )
 {
     size_t nItemPos = GetItemPos( nItemId );
     if ( nItemPos == THUMBNAILVIEW_ITEM_NOTFOUND )
@@ -1149,7 +1149,7 @@ void SfxThumbnailView::SelectItem( sal_uInt16 nItemId )
     ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::SELECTION_CHANGED, aOldAny, aNewAny );
 }
 
-bool SfxThumbnailView::IsItemSelected( sal_uInt16 nItemId ) const
+bool ThumbnailView::IsItemSelected( sal_uInt16 nItemId ) const
 {
     size_t nItemPos = GetItemPos( nItemId );
     if ( nItemPos == THUMBNAILVIEW_ITEM_NOTFOUND )
@@ -1159,7 +1159,7 @@ bool SfxThumbnailView::IsItemSelected( sal_uInt16 nItemId ) const
     return pItem->isSelected();
 }
 
-void SfxThumbnailView::deselectItems()
+void ThumbnailView::deselectItems()
 {
     for (std::unique_ptr<ThumbnailViewItem>& p : mItemList)
     {
@@ -1175,22 +1175,22 @@ void SfxThumbnailView::deselectItems()
         Invalidate();
 }
 
-void SfxThumbnailView::ShowTooltips( bool bShowTooltips )
+void ThumbnailView::ShowTooltips( bool bShowTooltips )
 {
     mbShowTooltips = bShowTooltips;
 }
 
-void SfxThumbnailView::DrawMnemonics( bool bDrawMnemonics )
+void ThumbnailView::DrawMnemonics( bool bDrawMnemonics )
 {
     mbDrawMnemonics = bDrawMnemonics;
 }
 
-void SfxThumbnailView::SetMultiSelectionEnabled( bool bIsMultiSelectionEnabled )
+void ThumbnailView::SetMultiSelectionEnabled( bool bIsMultiSelectionEnabled )
 {
     mbIsMultiSelectionEnabled = bIsMultiSelectionEnabled;
 }
 
-void SfxThumbnailView::filterItems(const std::function<bool (const ThumbnailViewItem*)> &func)
+void ThumbnailView::filterItems(const std::function<bool (const ThumbnailViewItem*)> &func)
 {
     mnFirstLine = 0;        // start at the top of the list instead of the current position
     maFilterFunc = func;
diff --git a/sfx2/source/control/thumbnailviewacc.cxx b/sfx2/source/control/thumbnailviewacc.cxx
index d439cf43d4cf..6bc148caf4c8 100644
--- a/sfx2/source/control/thumbnailviewacc.cxx
+++ b/sfx2/source/control/thumbnailviewacc.cxx
@@ -36,14 +36,14 @@
 
 using namespace ::com::sun::star;
 
-SfxThumbnailViewAcc::SfxThumbnailViewAcc( SfxThumbnailView* pParent ) :
+ThumbnailViewAcc::ThumbnailViewAcc( ThumbnailView* pParent ) :
     ValueSetAccComponentBase (m_aMutex),
     mpParent( pParent ),
     mbIsFocused(false)
 {
 }
 
-SfxThumbnailViewAcc::~SfxThumbnailViewAcc()
+ThumbnailViewAcc::~ThumbnailViewAcc()
 {
 }
 
@@ -52,17 +52,17 @@ namespace
     class theSfxValueSetAccUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSfxValueSetAccUnoTunnelId > {};
 }
 
-const uno::Sequence< sal_Int8 >& SfxThumbnailViewAcc::getUnoTunnelId()
+const uno::Sequence< sal_Int8 >& ThumbnailViewAcc::getUnoTunnelId()
 {
     return theSfxValueSetAccUnoTunnelId::get().getSeq();
 }
 
-SfxThumbnailViewAcc* SfxThumbnailViewAcc::getImplementation( const uno::Reference< uno::XInterface >& rxData )
+ThumbnailViewAcc* ThumbnailViewAcc::getImplementation( const uno::Reference< uno::XInterface >& rxData )
     throw()
 {
     try
     {
-        return comphelper::getUnoTunnelImplementation<SfxThumbnailViewAcc>(rxData);
+        return comphelper::getUnoTunnelImplementation<ThumbnailViewAcc>(rxData);
     }
     catch(const css::uno::Exception&)
     {
@@ -70,13 +70,13 @@ SfxThumbnailViewAcc* SfxThumbnailViewAcc::getImplementation( const uno::Referenc
     }
 }
 
-uno::Reference< accessibility::XAccessibleContext > SAL_CALL SfxThumbnailViewAcc::getAccessibleContext()
+uno::Reference< accessibility::XAccessibleContext > SAL_CALL ThumbnailViewAcc::getAccessibleContext()
 {
     ThrowIfDisposed();
     return this;
 }
 
-sal_Int32 SAL_CALL SfxThumbnailViewAcc::getAccessibleChildCount()
+sal_Int32 SAL_CALL ThumbnailViewAcc::getAccessibleChildCount()
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -85,7 +85,7 @@ sal_Int32 SAL_CALL SfxThumbnailViewAcc::getAccessibleChildCount()
     return nCount;
 }
 
-uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getAccessibleChild( sal_Int32 i )
+uno::Reference< accessibility::XAccessible > SAL_CALL ThumbnailViewAcc::getAccessibleChild( sal_Int32 i )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -98,14 +98,14 @@ uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getAc
     return xRet;
 }
 
-uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getAccessibleParent()
+uno::Reference< accessibility::XAccessible > SAL_CALL ThumbnailViewAcc::getAccessibleParent()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
     return mpParent->GetDrawingArea()->get_accessible_parent();
 }
 
-sal_Int32 SAL_CALL SfxThumbnailViewAcc::getAccessibleIndexInParent()
+sal_Int32 SAL_CALL ThumbnailViewAcc::getAccessibleIndexInParent()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -141,7 +141,7 @@ sal_Int32 SAL_CALL SfxThumbnailViewAcc::getAccessibleIndexInParent()
     return nRet;
 }
 
-sal_Int16 SAL_CALL SfxThumbnailViewAcc::getAccessibleRole()
+sal_Int16 SAL_CALL ThumbnailViewAcc::getAccessibleRole()
 {
     ThrowIfDisposed();
     // #i73746# As the Java Access Bridge (v 2.0.1) uses "managesDescendants"
@@ -149,13 +149,13 @@ sal_Int16 SAL_CALL SfxThumbnailViewAcc::getAccessibleRole()
     return accessibility::AccessibleRole::LIST;
 }
 
-OUString SAL_CALL SfxThumbnailViewAcc::getAccessibleDescription()
+OUString SAL_CALL ThumbnailViewAcc::getAccessibleDescription()
 {
     ThrowIfDisposed();
     return "ThumbnailView";
 }
 
-OUString SAL_CALL SfxThumbnailViewAcc::getAccessibleName()
+OUString SAL_CALL ThumbnailViewAcc::getAccessibleName()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -169,13 +169,13 @@ OUString SAL_CALL SfxThumbnailViewAcc::getAccessibleName()
     return aRet;
 }
 
-uno::Reference< accessibility::XAccessibleRelationSet > SAL_CALL SfxThumbnailViewAcc::getAccessibleRelationSet()
+uno::Reference< accessibility::XAccessibleRelationSet > SAL_CALL ThumbnailViewAcc::getAccessibleRelationSet()
 {
     ThrowIfDisposed();
     return uno::Reference< accessibility::XAccessibleRelationSet >();
 }
 
-uno::Reference< accessibility::XAccessibleStateSet > SAL_CALL SfxThumbnailViewAcc::getAccessibleStateSet()
+uno::Reference< accessibility::XAccessibleStateSet > SAL_CALL ThumbnailViewAcc::getAccessibleStateSet()
 {
     ThrowIfDisposed();
     ::utl::AccessibleStateSetHelper* pStateSet = new ::utl::AccessibleStateSetHelper();
@@ -191,7 +191,7 @@ uno::Reference< accessibility::XAccessibleStateSet > SAL_CALL SfxThumbnailViewAc
     return pStateSet;
 }
 
-lang::Locale SAL_CALL SfxThumbnailViewAcc::getLocale()
+lang::Locale SAL_CALL ThumbnailViewAcc::getLocale()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -209,7 +209,7 @@ lang::Locale SAL_CALL SfxThumbnailViewAcc::getLocale()
     return aRet;
 }
 
-void SAL_CALL SfxThumbnailViewAcc::addAccessibleEventListener( const uno::Reference< accessibility::XAccessibleEventListener >& rxListener )
+void SAL_CALL ThumbnailViewAcc::addAccessibleEventListener( const uno::Reference< accessibility::XAccessibleEventListener >& rxListener )
 {
     ThrowIfDisposed();
     ::osl::MutexGuard aGuard (m_aMutex);
@@ -232,7 +232,7 @@ void SAL_CALL SfxThumbnailViewAcc::addAccessibleEventListener( const uno::Refere
         mxEventListeners.push_back( rxListener );
 }
 
-void SAL_CALL SfxThumbnailViewAcc::removeAccessibleEventListener( const uno::Reference< accessibility::XAccessibleEventListener >& rxListener )
+void SAL_CALL ThumbnailViewAcc::removeAccessibleEventListener( const uno::Reference< accessibility::XAccessibleEventListener >& rxListener )
 {
     ThrowIfDisposed();
     ::osl::MutexGuard aGuard (m_aMutex);
@@ -247,7 +247,7 @@ void SAL_CALL SfxThumbnailViewAcc::removeAccessibleEventListener( const uno::Ref
     }
 }
 
-sal_Bool SAL_CALL SfxThumbnailViewAcc::containsPoint( const awt::Point& aPoint )
+sal_Bool SAL_CALL ThumbnailViewAcc::containsPoint( const awt::Point& aPoint )
 {
     ThrowIfDisposed();
     const awt::Rectangle    aRect( getBounds() );
@@ -257,7 +257,7 @@ sal_Bool SAL_CALL SfxThumbnailViewAcc::containsPoint( const awt::Point& aPoint )
     return tools::Rectangle( aNullPoint, aSize ).IsInside( aTestPoint );
 }
 
-uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getAccessibleAtPoint( const awt::Point& aPoint )
+uno::Reference< accessibility::XAccessible > SAL_CALL ThumbnailViewAcc::getAccessibleAtPoint( const awt::Point& aPoint )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -278,7 +278,7 @@ uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getAc
     return xRet;
 }
 
-awt::Rectangle SAL_CALL SfxThumbnailViewAcc::getBounds()
+awt::Rectangle SAL_CALL ThumbnailViewAcc::getBounds()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -294,7 +294,7 @@ awt::Rectangle SAL_CALL SfxThumbnailViewAcc::getBounds()
     return aRet;
 }
 
-awt::Point SAL_CALL SfxThumbnailViewAcc::getLocation()
+awt::Point SAL_CALL ThumbnailViewAcc::getLocation()
 {
     ThrowIfDisposed();
     const awt::Rectangle    aRect( getBounds() );
@@ -306,7 +306,7 @@ awt::Point SAL_CALL SfxThumbnailViewAcc::getLocation()
     return aRet;
 }
 
-awt::Point SAL_CALL SfxThumbnailViewAcc::getLocationOnScreen()
+awt::Point SAL_CALL ThumbnailViewAcc::getLocationOnScreen()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -317,7 +317,7 @@ awt::Point SAL_CALL SfxThumbnailViewAcc::getLocationOnScreen()
     {
         uno::Reference<accessibility::XAccessibleContext> xParentContext(xParent->getAccessibleContext());
         uno::Reference<accessibility::XAccessibleComponent> xParentComponent(xParentContext, css::uno::UNO_QUERY);
-        OSL_ENSURE( xParentComponent.is(), "SfxThumbnailViewAcc::getLocationOnScreen: no parent component!" );
+        OSL_ENSURE( xParentComponent.is(), "ThumbnailViewAcc::getLocationOnScreen: no parent component!" );
         if ( xParentComponent.is() )
         {
             awt::Point aParentScreenLoc( xParentComponent->getLocationOnScreen() );
@@ -330,7 +330,7 @@ awt::Point SAL_CALL SfxThumbnailViewAcc::getLocationOnScreen()
     return aScreenLoc;
 }
 
-awt::Size SAL_CALL SfxThumbnailViewAcc::getSize()
+awt::Size SAL_CALL ThumbnailViewAcc::getSize()
 {
     ThrowIfDisposed();
     const awt::Rectangle    aRect( getBounds() );
@@ -342,28 +342,28 @@ awt::Size SAL_CALL SfxThumbnailViewAcc::getSize()
     return aRet;
 }
 
-void SAL_CALL SfxThumbnailViewAcc::grabFocus()
+void SAL_CALL ThumbnailViewAcc::grabFocus()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
     mpParent->GrabFocus();
 }
 
-sal_Int32 SAL_CALL SfxThumbnailViewAcc::getForeground(  )
+sal_Int32 SAL_CALL ThumbnailViewAcc::getForeground(  )
 {
     ThrowIfDisposed();
     Color nColor = Application::GetSettings().GetStyleSettings().GetWindowTextColor();
     return static_cast<sal_Int32>(nColor);
 }
 
-sal_Int32 SAL_CALL SfxThumbnailViewAcc::getBackground(  )
+sal_Int32 SAL_CALL ThumbnailViewAcc::getBackground(  )
 {
     ThrowIfDisposed();
     Color nColor = Application::GetSettings().GetStyleSettings().GetWindowColor();
     return static_cast<sal_Int32>(nColor);
 }
 
-void SAL_CALL SfxThumbnailViewAcc::selectAccessibleChild( sal_Int32 nChildIndex )
+void SAL_CALL ThumbnailViewAcc::selectAccessibleChild( sal_Int32 nChildIndex )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -375,7 +375,7 @@ void SAL_CALL SfxThumbnailViewAcc::selectAccessibleChild( sal_Int32 nChildIndex
     mpParent->SelectItem( pItem->mnId );
 }
 
-sal_Bool SAL_CALL SfxThumbnailViewAcc::isAccessibleChildSelected( sal_Int32 nChildIndex )
+sal_Bool SAL_CALL ThumbnailViewAcc::isAccessibleChildSelected( sal_Int32 nChildIndex )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -387,18 +387,18 @@ sal_Bool SAL_CALL SfxThumbnailViewAcc::isAccessibleChildSelected( sal_Int32 nChi
     return mpParent->IsItemSelected( pItem->mnId );
 }
 
-void SAL_CALL SfxThumbnailViewAcc::clearAccessibleSelection()
+void SAL_CALL ThumbnailViewAcc::clearAccessibleSelection()
 {
     ThrowIfDisposed();
 }
 
-void SAL_CALL SfxThumbnailViewAcc::selectAllAccessibleChildren()
+void SAL_CALL ThumbnailViewAcc::selectAllAccessibleChildren()
 {
     ThrowIfDisposed();
     // unsupported due to single selection only
 }
 
-sal_Int32 SAL_CALL SfxThumbnailViewAcc::getSelectedAccessibleChildCount()
+sal_Int32 SAL_CALL ThumbnailViewAcc::getSelectedAccessibleChildCount()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -415,7 +415,7 @@ sal_Int32 SAL_CALL SfxThumbnailViewAcc::getSelectedAccessibleChildCount()
     return nRet;
 }
 
-uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
+uno::Reference< accessibility::XAccessible > SAL_CALL ThumbnailViewAcc::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -432,7 +432,7 @@ uno::Reference< accessibility::XAccessible > SAL_CALL SfxThumbnailViewAcc::getSe
     return xRet;
 }
 
-void SAL_CALL SfxThumbnailViewAcc::deselectAccessibleChild( sal_Int32 )
+void SAL_CALL ThumbnailViewAcc::deselectAccessibleChild( sal_Int32 )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -442,11 +442,11 @@ void SAL_CALL SfxThumbnailViewAcc::deselectAccessibleChild( sal_Int32 )
 //FIXME TODO        ;
 }
 
-sal_Int64 SAL_CALL SfxThumbnailViewAcc::getSomething( const uno::Sequence< sal_Int8 >& rId )
+sal_Int64 SAL_CALL ThumbnailViewAcc::getSomething( const uno::Sequence< sal_Int8 >& rId )
 {
     sal_Int64 nRet;
 
-    if( isUnoTunnelId<SfxThumbnailViewAcc>(rId) )
+    if( isUnoTunnelId<ThumbnailViewAcc>(rId) )
         nRet = reinterpret_cast< sal_Int64 >( this );
     else
         nRet = 0;
@@ -454,7 +454,7 @@ sal_Int64 SAL_CALL SfxThumbnailViewAcc::getSomething( const uno::Sequence< sal_I
     return nRet;
 }
 
-void SAL_CALL SfxThumbnailViewAcc::disposing()
+void SAL_CALL ThumbnailViewAcc::disposing()
 {
     ::std::vector<uno::Reference<accessibility::XAccessibleEventListener> > aListenerListCopy;
 
@@ -485,17 +485,17 @@ void SAL_CALL SfxThumbnailViewAcc::disposing()
     }
 }
 
-sal_uInt16 SfxThumbnailViewAcc::getItemCount() const
+sal_uInt16 ThumbnailViewAcc::getItemCount() const
 {
     return mpParent->ImplGetVisibleItemCount();
 }
 
-ThumbnailViewItem* SfxThumbnailViewAcc::getItem (sal_uInt16 nIndex) const
+ThumbnailViewItem* ThumbnailViewAcc::getItem (sal_uInt16 nIndex) const
 {
     return mpParent->ImplGetVisibleItem (nIndex);
 }
 
-void SfxThumbnailViewAcc::ThrowIfDisposed()
+void ThumbnailViewAcc::ThrowIfDisposed()
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose)
     {
@@ -526,7 +526,7 @@ void ThumbnailViewItemAcc::ParentDestroyed()
     mpParent = nullptr;
 }
 
-void SfxThumbnailViewAcc::FireAccessibleEvent( short nEventId, const uno::Any& rOldValue, const uno::Any& rNewValue )
+void ThumbnailViewAcc::FireAccessibleEvent( short nEventId, const uno::Any& rOldValue, const uno::Any& rNewValue )
 {
     if( !nEventId )
         return;
@@ -574,7 +574,7 @@ ThumbnailViewItemAcc* ThumbnailViewItemAcc::getImplementation( const uno::Refere
     }
 }
 
-void SfxThumbnailViewAcc::GetFocus()
+void ThumbnailViewAcc::GetFocus()
 {
     mbIsFocused = true;
 
@@ -586,7 +586,7 @@ void SfxThumbnailViewAcc::GetFocus()
         aOldState, aNewState);
 }
 
-void SfxThumbnailViewAcc::LoseFocus()
+void ThumbnailViewAcc::LoseFocus()
 {
     mbIsFocused = false;
 
diff --git a/sfx2/source/control/thumbnailviewacc.hxx b/sfx2/source/control/thumbnailviewacc.hxx
index 9679eaa3b8fa..b3083313a572 100644
--- a/sfx2/source/control/thumbnailviewacc.hxx
+++ b/sfx2/source/control/thumbnailviewacc.hxx
@@ -35,7 +35,7 @@
 #include <vcl/vclptr.hxx>
 #include <vector>
 
-class SfxThumbnailView;
+class ThumbnailView;
 class ThumbnailViewItem;
 
 typedef ::cppu::WeakComponentImplHelper<
@@ -47,14 +47,14 @@ typedef ::cppu::WeakComponentImplHelper<
     css::lang::XUnoTunnel >
     ValueSetAccComponentBase;
 
-class SfxThumbnailViewAcc :
+class ThumbnailViewAcc :
     public ::cppu::BaseMutex,
     public ValueSetAccComponentBase
 {
 public:
 
-    SfxThumbnailViewAcc( SfxThumbnailView* pParent );
-    virtual ~SfxThumbnailViewAcc() override;
+    ThumbnailViewAcc( ThumbnailView* pParent );
+    virtual ~ThumbnailViewAcc() override;
 
     void FireAccessibleEvent( short nEventId,
                               const css::uno::Any& rOldValue,
@@ -62,7 +62,7 @@ public:
 
     bool HasAccessibleListeners() const { return( mxEventListeners.size() > 0 ); }
 
-    static SfxThumbnailViewAcc* getImplementation( const css::uno::Reference< css::uno::XInterface >& rxData ) throw();
+    static ThumbnailViewAcc* getImplementation( const css::uno::Reference< css::uno::XInterface >& rxData ) throw();
 
 public:
     /** Called by the corresponding ValueSet when it gets the focus.
@@ -121,7 +121,7 @@ public:
 private:
     ::std::vector< css::uno::Reference<
         css::accessibility::XAccessibleEventListener > >   mxEventListeners;
-    SfxThumbnailView*                                               mpParent;
+    ThumbnailView*                                               mpParent;
     /// The current FOCUSED state.
     bool mbIsFocused;
 
diff --git a/sfx2/source/inc/templatesearchview.hxx b/sfx2/source/inc/templatesearchview.hxx
index 69073653be2a..5dc23adfd8b4 100644
--- a/sfx2/source/inc/templatesearchview.hxx
+++ b/sfx2/source/inc/templatesearchview.hxx
@@ -16,7 +16,7 @@ class TemplateViewItem;
 class PopupMenu;
 class Menu;
 
-class TemplateSearchView final : public SfxThumbnailView
+class TemplateSearchView final : public ThumbnailView
 {
 public:
 


More information about the Libreoffice-commits mailing list
diff --git a/include/sfx2/thumbnailview.hxx b/include/sfx2/thumbnailview.hxx
index 93d67e8928bb..f38b41c8b4b2 100644
--- a/include/sfx2/thumbnailview.hxx
+++ b/include/sfx2/thumbnailview.hxx
@@ -181,12 +181,12 @@ public:
     virtual ~ThumbnailViewBase();
 };
 
-class SFX2_DLLPUBLIC SfxThumbnailView : public weld::CustomWidgetController, public ThumbnailViewBase
+class SFX2_DLLPUBLIC ThumbnailView : public weld::CustomWidgetController, public ThumbnailViewBase
 {
 public:
-    SfxThumbnailView(std::unique_ptr<weld::ScrolledWindow> xWindow, std::unique_ptr<weld::Menu> xMenu);
+    ThumbnailView(std::unique_ptr<weld::ScrolledWindow> xWindow, std::unique_ptr<weld::Menu> xMenu);
 
-    virtual ~SfxThumbnailView() override;
+    virtual ~ThumbnailView() override;
 
     virtual bool MouseMove(const MouseEvent& rMEvt) override;
 
@@ -280,12 +280,12 @@ protected:
 
     virtual void OnItemDblClicked (ThumbnailViewItem *pItem);
 
     // Set Item colors from the SfxThumbnailView colors
     void UpdateColors();
 
 protected:
 
-    friend class SfxThumbnailViewAcc;
+    friend class ThumbnailViewAcc;
     friend class ThumbnailViewItemAcc;
 
     void CalculateItemPositions (bool bScrollBarUsed = false);
@@ -280,12 +280,12 @@ protected:
     virtual void OnItemDblClicked (ThumbnailViewItem *pItem);
 
-    // Set Item colors from the SfxThumbnailView colors
+    // Set Item colors from the ThumbnailView colors
     void UpdateColors();
 
diff --git a/sfx2/source/control/recentdocsview.cxx b/sfx2/source/control/recentdocsview.cxx
index 83b0cb2fed82..62eacf3734fe 100644
--- a/sfx2/source/control/recentdocsview.cxx
+++ b/sfx2/source/control/recentdocsview.cxx
@@ -123,7 +123,7 @@ constexpr tools::Long gnTextHeight = 30;
 constexpr tools::Long gnItemPadding = 5;
 
 RecentDocsView::RecentDocsView(std::unique_ptr<weld::ScrolledWindow> xWindow, std::unique_ptr<weld::Menu> xMenu)
-    : SfxThumbnailView(std::move(xWindow), std::move(xMenu))
+    : ThumbnailView(std::move(xWindow), std::move(xMenu))
     , mnFileTypes(ApplicationType::TYPE_NONE)
     , mnLastMouseDownItem(THUMBNAILVIEW_ITEM_NOTFOUND)
     , maWelcomeImage()
@@ -304,11 +304,11 @@ bool RecentDocsView::MouseButtonDown( const MouseEvent& rMEvt )
     {
         mnLastMouseDownItem = ImplGetItem(rMEvt.GetPosPixel());
 
         // ignore to avoid stuff done in SfxThumbnailView; we don't do selections etc.
         return true;
     }
 
-    return SfxThumbnailView::MouseButtonDown(rMEvt);
+    return ThumbnailView::MouseButtonDown(rMEvt);
 }
 
 bool RecentDocsView::MouseButtonUp(const MouseEvent& rMEvt)
@@ -335,7 +335,7 @@ bool RecentDocsView::MouseButtonUp(const MouseEvent& rMEvt)
         if (pItem)
             return true;
     }
-    return SfxThumbnailView::MouseButtonUp(rMEvt);
+    return ThumbnailView::MouseButtonUp(rMEvt);
 }
 
 void RecentDocsView::OnItemDblClicked(ThumbnailViewItem *pItem)
@@ -347,7 +347,7 @@ void RecentDocsView::OnItemDblClicked(ThumbnailViewItem *pItem)
 
 void RecentDocsView::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle &aRect)
 {
-    SfxThumbnailView::Paint(rRenderContext, aRect);
+    ThumbnailView::Paint(rRenderContext, aRect);
 
     if (mItemList.empty())
     {
@@ -388,13 +388,13 @@ void RecentDocsView::LoseFocus()
 {
     deselectItems();
 
-    SfxThumbnailView::LoseFocus();
+    ThumbnailView::LoseFocus();
 }
 
 void RecentDocsView::Clear()
 {
     Invalidate();
-    SfxThumbnailView::Clear();
+    ThumbnailView::Clear();
 }
 
 void RecentDocsView::PostLoadRecentUsedFile(LoadRecentFile* pLoadRecentFile)
@@ -304,11 +304,11 @@ bool RecentDocsView::MouseButtonDown( const MouseEvent& rMEvt )
         mnLastMouseDownItem = ImplGetItem(rMEvt.GetPosPixel());
 
-        // ignore to avoid stuff done in SfxThumbnailView; we don't do selections etc.
+        // ignore to avoid stuff done in ThumbnailView; we don't do selections etc.
         return true;
     }